Installation
============

You can use pip_ to install wheel::

    pip install wheel

If you do not have pip_ installed, see its documentation for
`installation instructions`_.

If you prefer using your system package manager to install Python packages, you
can typically find the wheel package under one of the following package names:

* python-wheel
* python3-wheel

.. _pip: https://pip.pypa.io/en/stable/
.. _installation instructions: https://pip.pypa.io/en/stable/installing/

Python and OS Compatibility
---------------------------

wheel should work on any Python implementation and operating system and is
compatible with Python version 3.7 and upwards.
